==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/DateTimeCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { DateTimeCellInfoDescription } from "./DateTimeCellInfoDescription";
/**
 * @hidden
 */
var DateTimeCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DateTimeCellInfoDescriptionMetadata, _super);
    function DateTimeCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DateTimeCellInfoDescriptionMetadata.b = function (a) {
        if (DateTimeCellInfoDescriptionMetadata.a == null) {
            DateTimeCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DateTimeCellInfoDescriptionMetadata.c(DateTimeCellInfoDescriptionMetadata.a);
        }
        if (a.g(DateTimeCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.s(DateTimeCellInfoDescriptionMetadata.a);
    };
    DateTimeCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("DateTimeValue", "Date");
        a.item("FormatStringOverride", "String");
        a.item("FormatSpecifiers", "Collection:FormatSpecifier:FormatSpecifierCollection:FormatSpecifier");
        a.item("FormatOverrideRef", "(w:FormatOverride,wf:FormatOverride)DataRef");
        a.item("DateTimeFormat", "ExportedType:string:DateTimeFormats");
        a.item("DateTimeFormat@names", "DateShort;DateLong;TimeShort;TimeLong;DateTimeShort;DateTimeLong");
        a.item("IsOffsetValue", "Boolean");
    };
    DateTimeCellInfoDescriptionMetadata.d = function (a) {
        DateTimeCellInfoDescriptionMetadata.b(a);
        a.u("DateTimeCellInfo", function () { return new DateTimeCellInfoDescription(); });
        a.t("DateTimeCellInfo", DateTimeCellInfoDescriptionMetadata.a);
    };
    DateTimeCellInfoDescriptionMetadata.$t = markType(DateTimeCellInfoDescriptionMetadata, 'DateTimeCellInfoDescriptionMetadata');
    DateTimeCellInfoDescriptionMetadata.a = null;
    return DateTimeCellInfoDescriptionMetadata;
}(Base));
export { DateTimeCellInfoDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/DateTimeCellInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CellInfoDescriptionMetadata } from "./CellInfoDescriptionMetadata";
import { DateTimeCellInfoDescription } from "./DateTimeCellInfoDescription";
/**
 * @hidden
 */
var DateTimeCellInfoDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DateTimeCellInfoDescriptionMetadata, _super);
    function DateTimeCellInfoDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DateTimeCellInfoDescriptionMetadata.b = function (a) {
        if (DateTimeCellInfoDescriptionMetadata.a == null) {
            DateTimeCellInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DateTimeCellInfoDescriptionMetadata.c(DateTimeCellInfoDescriptionMetadata.a);
        }
        if (a.j(DateTimeCellInfoDescriptionMetadata.a)) {
            return;
        }
        a.y(DateTimeCellInfoDescriptionMetadata.a);
    };
    DateTimeCellInfoDescriptionMetadata.c = function (a) {
        CellInfoDescriptionMetadata.c(a);
        a.item("DateTimeValue", "Date");
        a.item("FormatStringOverride", "String");
        a.item("FormatSpecifiers", "Collection:FormatSpecifier:FormatSpecifierCollection:FormatSpecifier");
        a.item("FormatOverrideRef", "(w:FormatOverride,wf:FormatOverride)DataRef");
        a.item("DateTimeFormat", "ExportedType:string:DateTimeFormats");
        a.item("DateTimeFormat@names", "DateShort;DateLong;TimeShort;TimeLong;DateTimeShort;DateTimeLong");
        a.item("IsOffsetValue", "Boolean");
    };
    DateTimeCellInfoDescriptionMetadata.d = function (a) {
        DateTimeCellInfoDescriptionMetadata.b(a);
        a.aa("DateTimeCellInfo", function () { return new DateTimeCellInfoDescription(); });
        a.z("DateTimeCellInfo", DateTimeCellInfoDescriptionMetadata.a);
    };
    DateTimeCellInfoDescriptionMetadata.$t = markType(DateTimeCellInfoDescriptionMetadata, 'DateTimeCellInfoDescriptionMetadata');
    DateTimeCellInfoDescriptionMetadata.a = null;
    return DateTimeCellInfoDescriptionMetadata;
}(Base));
export { DateTimeCellInfoDescriptionMetadata };
